@@ -32,7 +32,9 @@ from searx.plugins import (oa_doi_rewrite,
                            https_rewrite,
                            infinite_scroll,
                            self_info,
+                           hostname_replace,
                            search_on_category_select,
+                           search_operators,
                            tracker_url_remover,
                            vim_hotkeys)
 
@@ -168,9 +170,12 @@ plugins.register(hash_plugin)
 plugins.register(https_rewrite)
 plugins.register(infinite_scroll)
 plugins.register(self_info)
+plugins.register(hostname_replace)
 plugins.register(search_on_category_select)
+plugins.register(search_operators)
 plugins.register(tracker_url_remover)
 plugins.register(vim_hotkeys)
+
 # load external plugins
 if 'plugins' in settings:
     plugins.register(*settings['plugins'], external=True)
