@@ -29,7 +29,7 @@ def get_doi_resolver(args, preference_doi_resolver):
     doi_resolvers = settings['doi_resolvers']
     doi_resolver = args.get('doi_resolver', preference_doi_resolver)[0]
     if doi_resolver not in doi_resolvers:
-        doi_resolvers = settings['default_doi_resolver']
+        doi_resolver = settings['default_doi_resolver']
     doi_resolver_url = doi_resolvers[doi_resolver]
     return doi_resolver_url
 
@@ -40,7 +40,7 @@ def on_result(request, search, result):
 
     doi = extract_doi(result['parsed_url'])
     if doi and len(doi) < 50:
-        for suffix in ('/', '.pdf', '/full', '/meta', '/abstract'):
+        for suffix in ('/', '.pdf', '.xml', '/full', '/meta', '/abstract'):
             if doi.endswith(suffix):
                 doi = doi[:-len(suffix)]
         result['url'] = get_doi_resolver(request.args, request.preferences.get_value('doi_resolver')) + doi
