@@ -1,10 +1,13 @@
 import re
+from collections import defaultdict
 from operator import itemgetter
 from threading import RLock
 from urllib.parse import urlparse, unquote
 from searx import logger
 from searx.engines import engines
 from searx.metrology.error_recorder import record_error
+from searx.utils import add_scheme_to_url
+from searx import settings
 
 
 CONTENT_LEN_IGNORED_CHARS_REGEX = re.compile(r'[,;:!?\./\\\\ ()-_]', re.M | re.U)
@@ -128,13 +131,18 @@ def merge_two_infoboxes(infobox1, infobox2):
             infobox1['content'] = content2
 
 
-def result_score(result):
+def result_score(result, language):
     weight = 1.0
 
     for result_engine in result['engines']:
         if hasattr(engines[result_engine], 'weight'):
             weight *= float(engines[result_engine].weight)
 
+    if settings['search'].get('prefer_configured_language', False):
+        domain_parts = result['parsed_url'].netloc.split('.')
+        if language in domain_parts:
+            weight *= 1.1
+
     occurences = len(result['positions'])
 
     return sum((occurences * weight) / position for position in result['positions'])
@@ -144,9 +152,10 @@ class ResultContainer:
     """docstring for ResultContainer"""
 
     __slots__ = '_merged_results', 'infoboxes', 'suggestions', 'answers', 'corrections', '_number_of_results',\
-                '_ordered', 'paging', 'unresponsive_engines', 'timings', 'redirect_url'
+                '_ordered', 'paging', 'unresponsive_engines', 'timings', 'redirect_url', 'engine_data',\
+                '_language'
 
-    def __init__(self):
+    def __init__(self, language):
         super().__init__()
         self._merged_results = []
         self.infoboxes = []
@@ -154,11 +163,13 @@ class ResultContainer:
         self.answers = {}
         self.corrections = set()
         self._number_of_results = []
+        self.engine_data = defaultdict(dict)
         self._ordered = False
         self.paging = False
         self.unresponsive_engines = set()
         self.timings = []
         self.redirect_url = None
+        self._language = language.lower().split('-')[0]
 
     def extend(self, engine_name, results):
         standard_result_count = 0
@@ -175,6 +186,8 @@ class ResultContainer:
                 self._merge_infobox(result)
             elif 'number_of_results' in result:
                 self._number_of_results.append(result['number_of_results'])
+            elif 'engine_data' in result:
+                self.engine_data[engine_name][result['key']] = result['engine_data']
             else:
                 # standard result (url, title, content)
                 if 'url' in result and not isinstance(result['url'], str):
@@ -228,10 +241,15 @@ class ResultContainer:
         result['parsed_url'] = urlparse(result['url'])
 
         # if the result has no scheme, use http as default
-        if not result['parsed_url'].scheme:
-            result['parsed_url'] = result['parsed_url']._replace(scheme="http")
+        if not result['parsed_url'].scheme or result['parsed_url'].scheme == '':
+            result['parsed_url'] = result['parsed_url']._replace(scheme='http')
             result['url'] = result['parsed_url'].geturl()
 
+        if 'thumbnail_src' in result:
+            result['thumbnail_src'] = add_scheme_to_url(result['thumbnail_src'])
+        if 'img_src' in result:
+            result['img_src'] = add_scheme_to_url(result['img_src'])
+
         result['engines'] = set([result['engine']])
 
         # strip multiple spaces and cariage returns from content
@@ -295,7 +313,7 @@ class ResultContainer:
 
     def order_results(self):
         for result in self._merged_results:
-            score = result_score(result)
+            score = result_score(result, self._language)
             result['score'] = score
             with RLock():
                 for result_engine in result['engines']:
