@@ -40,7 +40,8 @@ from datetime import datetime, timedelta
 from time import time
 from html import escape
 from io import StringIO
-from urllib.parse import urlencode, urljoin, urlparse
+import urllib
+from urllib.parse import urlencode, urlparse
 
 from pygments import highlight
 from pygments.lexers import get_lexer_by_name
@@ -82,6 +83,7 @@ from searx.answerers import answerers
 from searx.poolrequests import get_global_proxies
 from searx.answerers import ask
 from searx.metrology.error_recorder import errors_per_engines
+from searx.settings_loader import get_default_settings_path
 
 # serve pages with HTTP/1.1
 from werkzeug.serving import WSGIRequestHandler
@@ -209,7 +211,10 @@ def get_locale():
         request.form['use-translation'] = 'oc'
         locale = 'fr_FR'
 
-    logger.debug("%s uses locale `%s` from %s", request.url, locale, locale_source)
+    logger.debug(
+        "%s uses locale `%s` from %s", urllib.parse.quote(request.url), locale, locale_source
+    )
+
     return locale
 
 
@@ -270,14 +275,7 @@ def extract_domain(url):
 
 
 def get_base_url():
-    if settings['server']['base_url']:
-        hostname = settings['server']['base_url']
-    else:
-        scheme = 'http'
-        if request.is_secure:
-            scheme = 'https'
-        hostname = url_for('index', _external=True, _scheme=scheme)
-    return hostname
+    return url_for('index', _external=True)
 
 
 def get_current_theme_name(override=None):
@@ -310,10 +308,6 @@ def url_for_theme(endpoint, override_theme=None, **values):
         if filename_with_theme in static_files:
             values['filename'] = filename_with_theme
     url = url_for(endpoint, **values)
-    if settings['server']['base_url']:
-        if url.startswith('/'):
-            url = url[1:]
-        url = urljoin(settings['server']['base_url'], url)
     return url
 
 
@@ -364,8 +358,6 @@ def image_proxify(url):
 
 def get_translations():
     return {
-        # when overpass AJAX request fails (on a map result)
-        'could_not_load': gettext('could not load data'),
         # when there is autocompletion
         'no_item_found': gettext('No item found')
     }
@@ -395,6 +387,10 @@ def render(template_name, override_theme=None, **kwargs):
 
     kwargs['method'] = request.preferences.get_value('method')
 
+    kwargs['autofocus'] = request.preferences.get_value('autofocus')
+
+    kwargs['archive_today'] = request.preferences.get_value('archive_today')
+
     kwargs['safesearch'] = str(request.preferences.get_value('safesearch'))
 
     kwargs['language_codes'] = languages
@@ -579,6 +575,11 @@ def index():
     )
 
 
+@app.route('/healthz', methods=['GET'])
+def health():
+    return Response('OK', mimetype='text/plain')
+
+
 @app.route('/search', methods=['GET', 'POST'])
 def search():
     """Search query in q and return results.
@@ -650,7 +651,7 @@ def search():
             result['pretty_url'] = prettify_url(result['url'])
 
         # TODO, check if timezone is calculated right
-        if 'publishedDate' in result:
+        if result.get('publishedDate'):  # do not try to get a date from an empty string or a None type
             try:  # test if publishedDate >= 1900 (datetime module bug)
                 result['pubdate'] = result['publishedDate'].strftime('%Y-%m-%d %H:%M:%S%z')
             except ValueError:
@@ -785,20 +786,26 @@ def autocompleter():
 
     # parse query
     raw_text_query = RawTextQuery(request.form.get('q', ''), disabled_engines)
+    sug_prefix = raw_text_query.getQuery()
 
     # normal autocompletion results only appear if no inner results returned
     # and there is a query part
-    if len(raw_text_query.autocomplete_list) == 0 and len(raw_text_query.getQuery()) > 0:
+    if len(raw_text_query.autocomplete_list) == 0 and len(sug_prefix) > 0:
+
         # get language from cookie
         language = request.preferences.get_value('language')
         if not language or language == 'all':
             language = 'en'
         else:
             language = language.split('-')[0]
+
         # run autocompletion
-        raw_results = search_autocomplete(request.preferences.get_value('autocomplete'),
-                                          raw_text_query.getQuery(), language)
+        raw_results = search_autocomplete(
+            request.preferences.get_value('autocomplete'), sug_prefix, language
+        )
         for result in raw_results:
+            # attention: this loop will change raw_text_query object and this is
+            # the reason why the sug_prefix was stored before (see above)
             results.append(raw_text_query.changeQuery(result).getFullQuery())
 
     if len(raw_text_query.autocomplete_list) > 0:
@@ -809,13 +816,16 @@ def autocompleter():
         for answer in answers:
             results.append(str(answer['answer']))
 
-    # return autocompleter results
     if request.headers.get('X-Requested-With') == 'XMLHttpRequest':
-        return Response(json.dumps(results),
-                        mimetype='application/json')
+        # the suggestion request comes from the searx search form
+        suggestions = json.dumps(results)
+        mimetype = 'application/json'
+    else:
+        # the suggestion request comes from browser's URL bar
+        suggestions = json.dumps([sug_prefix, results])
+        mimetype = 'application/x-suggestions+json'
 
-    return Response(json.dumps([raw_text_query.query, results]),
-                    mimetype='application/x-suggestions+json')
+    return Response(suggestions, mimetype=mimetype)
 
 
 @app.route('/preferences', methods=['GET', 'POST'])
@@ -824,7 +834,7 @@ def preferences():
 
     # save preferences
     if request.method == 'POST':
-        resp = make_response(redirect(urljoin(settings['server']['base_url'], url_for('index'))))
+        resp = make_response(redirect(url_for('index', _external=True)))
         try:
             request.preferences.parse_form(request.form)
         except ValidationException:
@@ -911,8 +921,14 @@ def image_proxy():
     if h != request.args.get('h'):
         return '', 400
 
+    headers = {
+        'User-Agent': gen_useragent(),
+        'Accept': 'image/webp,*/*',
+        'Accept-Encoding': 'gzip, deflate',
+        'Sec-GPC': '1',
+        'DNT': '1',
+    }
     headers = dict_subset(request.headers, {'If-Modified-Since', 'If-None-Match'})
-    headers['User-Agent'] = gen_useragent()
 
     resp = requests.get(url,
                         stream=True,
@@ -950,6 +966,8 @@ def image_proxy():
 @app.route('/stats', methods=['GET'])
 def stats():
     """Render engine statistics page."""
+    if not settings['general'].get('enable_stats'):
+        return page_not_found(None)
     stats = get_engines_stats(request.preferences)
     return render(
         'stats.html',
@@ -1013,11 +1031,11 @@ def opensearch():
     if request.headers.get('User-Agent', '').lower().find('webkit') >= 0:
         method = 'get'
 
-    ret = render('opensearch.xml',
-                 opensearch_method=method,
-                 host=get_base_url(),
-                 urljoin=urljoin,
-                 override_theme='__common__')
+    ret = render(
+        'opensearch.xml',
+        opensearch_method=method,
+        override_theme='__common__'
+    )
 
     resp = Response(response=ret,
                     status=200,
@@ -1038,7 +1056,7 @@ def favicon():
 
 @app.route('/clear_cookies')
 def clear_cookies():
-    resp = make_response(redirect(urljoin(settings['server']['base_url'], url_for('index'))))
+    resp = make_response(redirect(url_for('index', _external=True)))
     for cookie_name in request.cookies:
         resp.delete_cookie(cookie_name)
     return resp
@@ -1087,6 +1105,7 @@ def config():
         'brand': {
             'CONTACT_URL': brand.CONTACT_URL,
             'GIT_URL': brand.GIT_URL,
+            'GIT_BRANCH': brand.GIT_BRANCH,
             'DOCS_URL': brand.DOCS_URL
         },
         'doi_resolvers': [r for r in settings['doi_resolvers']],
@@ -1106,10 +1125,20 @@ def run():
         use_debugger=searx_debug,
         port=settings['server']['port'],
         host=settings['server']['bind_address'],
-        threaded=True
+        threaded=True,
+        extra_files=[
+            get_default_settings_path()
+        ],
     )
 
 
+def patch_application(app):
+    # serve pages with HTTP/1.1
+    WSGIRequestHandler.protocol_version = "HTTP/{}".format(settings['server']['http_protocol_version'])
+    # patch app to handle non root url-s behind proxy & wsgi
+    app.wsgi_app = ReverseProxyPathFix(ProxyFix(app.wsgi_app))
+
+
 class ReverseProxyPathFix:
     '''Wrap the application in this middleware and configure the
     front-end server to add these headers, to let you quietly bind
@@ -1131,19 +1160,41 @@ class ReverseProxyPathFix:
     '''
 
     def __init__(self, app):
+
         self.app = app
+        self.script_name = None
+        self.scheme = None
+        self.server = None
+
+        if settings['server']['base_url']:
+
+            # If base_url is specified, then these values from are given
+            # preference over any Flask's generics.
+
+            base_url = urlparse(settings['server']['base_url'])
+            self.script_name = base_url.path
+            if self.script_name.endswith('/'):
+                # remove trailing slash to avoid infinite redirect on the index
+                # see https://github.com/searx/searx/issues/2729
+                self.script_name = self.script_name[:-1]
+            self.scheme = base_url.scheme
+            self.server = base_url.netloc
 
     def __call__(self, environ, start_response):
-        script_name = environ.get('HTTP_X_SCRIPT_NAME', '')
+        script_name = self.script_name or environ.get('HTTP_X_SCRIPT_NAME', '')
         if script_name:
             environ['SCRIPT_NAME'] = script_name
             path_info = environ['PATH_INFO']
             if path_info.startswith(script_name):
                 environ['PATH_INFO'] = path_info[len(script_name):]
 
-        scheme = environ.get('HTTP_X_SCHEME', '')
+        scheme = self.scheme or environ.get('HTTP_X_SCHEME', '')
         if scheme:
             environ['wsgi.url_scheme'] = scheme
+
+        server = self.server or environ.get('HTTP_X_FORWARDED_HOST', '')
+        if server:
+            environ['HTTP_HOST'] = server
         return self.app(environ, start_response)
 
 
